// Copyright (C) 2019 Miroslav Mazel
//
// This file is part of Feeel.
//
// Feeel is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version. As an additional permission under
// section 7, you are allowed to distribute the software through an app
// store, even if that store has restrictive terms and conditions that
// are incompatible with the AGPL, provided that the source is also
// available under the AGPL with or without this permission through a
// channel without those restrictive terms and conditions.
//
// Feeel is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with Feeel.  If not, see <http://www.gnu.org/licenses/>.

import 'package:feeel/models/editor/editor_workout_exercise.dart';
import 'package:flutter/material.dart';
import 'package:feeel/i18n/translations.dart';

import 'exercise_editor_row.dart';

class WorkoutContentEditor extends StatelessWidget {
  final Widget header;
  final Widget subheader;
  final List<EditorWorkoutExercise> workoutExercises;
  final Function(int) onRemove;
  final Function(int, int) onReorder;

  const WorkoutContentEditor(
      {Key? key,
      required this.header,
      required this.subheader,
      required this.workoutExercises,
      required this.onRemove,
      required this.onReorder})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(children: [
      header,
      subheader,
      const SizedBox(
        height: 16,
      ),
      Expanded(
          child: ReorderableListView.builder(
              //todo somehow, this seems to no longer work on Android; could it be the onPressed aspect of the drag handle?
              buildDefaultDragHandles: false,
              padding: const EdgeInsets.only(bottom: 32),
              itemBuilder: (context, i) {
                final editableExercise = workoutExercises[i];
                return ExerciseEditorRow(
                    key: editableExercise.key,
                    workoutExercise: editableExercise.exercise,
                    trailing: Row(children: [
                      IconButton(
                          icon: const Icon(Icons.delete),
                          tooltip: "Delete".i18n,
                          onPressed: () {
                            onRemove(i);
                          }),
                      ReorderableDragStartListener(
                        index: i,
                        child: IconButton(
                            onPressed: () {
                              ScaffoldMessenger.of(context).showSnackBar(SnackBar(
                                  content: Text(
                                      "Drag this handle to reorder exercises."
                                          .i18n)));
                              //todo test this, shouldn't show up on drag
                            },
                            icon: const Icon(Icons.drag_handle)),
                      )
                    ]));
              },
              itemCount: workoutExercises.length,
              onReorder: onReorder))
    ]);
  }
}
